@@ -1,6 +1,11 @@
 use {super::*, clap_mangen::Man};
 
-const INIT_JUSTFILE: &str = "default:\n    echo 'Hello, world!'\n";
+pub const INIT_JUSTFILE: &str = "\
+# https://just.systems
+
+default:
+    echo 'Hello, world!'
+";
 
 fn backtick_re() -> &'static Regex {
   static BACKTICK_RE: OnceLock<Regex> = OnceLock::new();
@@ -61,6 +66,7 @@ impl Subcommand {
       Completions { shell } => return Self::completions(*shell),
       Init => return Self::init(config),
       Man => return Self::man(),
+      Request { request } => return Self::request(request),
       _ => {}
     }
 
@@ -84,7 +90,6 @@ impl Subcommand {
       Format => Self::format(config, &search, compilation)?,
       Groups => Self::groups(config, justfile),
       List { path } => Self::list(config, justfile, path)?,
-      Request { request } => Self::request(request)?,
       Run {
         arguments,
         overrides,
@@ -92,7 +97,7 @@ impl Subcommand {
       Show { path } => Self::show(config, justfile, path)?,
       Summary => Self::summary(config, justfile),
       Variables => Self::variables(justfile),
-      Changelog | Completions { .. } | Edit | Init | Man => unreachable!(),
+      Changelog | Completions { .. } | Edit | Init | Man | Request { .. } => unreachable!(),
     }
 
     Ok(())
@@ -241,7 +246,7 @@ impl Subcommand {
 
     let stdin = child.stdin.as_mut().unwrap();
     for recipe in recipes {
-      if let Err(io_error) = writeln!(stdin, "{}", recipe.namepath.spaced()) {
+      if let Err(io_error) = writeln!(stdin, "{}", recipe.spaced_namepath()) {
         if io_error.kind() != std::io::ErrorKind::BrokenPipe {
           return Err(Error::ChooserWrite { io_error, chooser });
         }
@@ -406,6 +411,16 @@ impl Subcommand {
   fn request(request: &Request) -> RunResult<'static> {
     let response = match request {
       Request::EnvironmentVariable(key) => Response::EnvironmentVariable(env::var_os(key)),
+      #[cfg(not(windows))]
+      Request::Signal => {
+        let sigset = nix::sys::signal::SigSet::all();
+
+        sigset.thread_block().unwrap();
+
+        let received = sigset.wait().unwrap();
+
+        Response::Signal(received.as_str().into())
+      }
     };
 
     serde_json::to_writer(io::stdout(), &response).map_err(|source| Error::DumpJson { source })?;
